@@ -459,7 +459,7 @@ conversions possible are:
 
 =over 8
 
-=item * year <=> months
+=item * years <=> months
 
 =item * weeks <=> days
 
@@ -511,8 +511,8 @@ Returns one of "wrap", "limit", or "preserve".
 
 =item * calendar_duration
 
-Returns a new object with the same I<calendar> delta (months only) and
-end of month mode as the current object.
+Returns a new object with the same I<calendar> delta (months and days
+only) and end of month mode as the current object.
 
 =item * clock_duration
 
@@ -546,7 +546,7 @@ This is a class method that can be used to compare or sort durations.
 Comparison is done by adding each duration to the specified
 C<DateTime.pm> object and comparing the resulting datetimes.  This is
 necessary because without a base, many durations are not comparable.
-For example, 1 month may otr may not be longer than 29 days, depending
+For example, 1 month may or may not be longer than 29 days, depending
 on what datetime it is added to.
 
 If no base datetime is given, then the result of C<< DateTime->now >>
@@ -555,8 +555,9 @@ if used to compare two duration objects containing different units.
 It will also give non-repeatable results if the durations contain
 multiple types of units, such as months and days.
 
-However, if you know that both objects only contain the same units,
-and just a single I<type>, then the results of the comparison will be
+However, if you know that both objects only consist of one type of
+unit (months I<or> days I<or> hours, etc.), and each duration contains
+the same type of unit, then the results of the comparison will be
 repeatable.
 
 =item * years, months, weeks, days, hours, minutes, seconds, nanoseconds
@@ -568,14 +569,14 @@ is returned.  These numbers are always positive.
 
 Here's what each method returns:
 
- $dur->year()    == abs( $dur->in_units('years') )
- $dur->months()  == ( abs( $dur->in_units( 'months', 'years' ) ) )[0]
- $dur->weeks()   == abs( $dur->in_units( 'weeks' ) )
- $dur->days()    == ( abs( $dur->in_units( 'days', 'weeks' ) ) )[0]
- $dur->hours()   == abs( $dur->in_units( 'hours' ) )
- $dur->minutes   == ( abs( $dur->in_units( 'minutes', 'hours' ) ) )[0]
- $dur->seconds   == abs( $dur->in_units( 'seconds' ) )
- $dur->nanoseconds() == abs( $dur->in_units( 'nanoseconds', 'seconds' ) )
+ $dur->years()       == abs( $dur->in_units('years') )
+ $dur->months()      == abs( ( $dur->in_units( 'months', 'years' ) )[0] )
+ $dur->weeks()       == abs( $dur->in_units( 'weeks' ) )
+ $dur->days()        == abs( ( $dur->in_units( 'days', 'weeks' ) )[0] )
+ $dur->hours()       == abs( $dur->in_units( 'hours' ) )
+ $dur->minutes       == abs( ( $dur->in_units( 'minutes', 'hours' ) )[0] )
+ $dur->seconds       == abs( $dur->in_units( 'seconds' ) )
+ $dur->nanoseconds() == abs( ( $dur->in_units( 'nanoseconds', 'seconds' ) )[0] )
 
 If this seems confusing, remember that you can always use the
 C<in_units()> method to specify exactly what you want.
